diff --git a/doc/drivers.html b/doc/drivers.html
index f8893001d237e2df55dde42398175d9a9f25eda4..bfffb4446f697352e36adb0d2237266e7ee1d0e2 100644
--- a/doc/drivers.html
+++ b/doc/drivers.html
@@ -97,7 +97,7 @@ Linux and FreeBSD as well as some other UNIX-like systems.
 
 <b>Option keys:</b>
 <ul>
-<li>"dev" - The dsp device.  By default, the driver tries
+<li>"dsp" - The dsp device.  By default, the driver tries
 "/dev/sound/dsp", followed by "/dev/dsp".
 </ul>
 <p>
diff --git a/src/plugins/oss/ao_oss.c b/src/plugins/oss/ao_oss.c
index 78229396173077fd891fa83ca793b2f5e57fb6d3..ab845c01066ceef6f8eb9a6ef5c622cd5fe9a17c 100644
--- a/src/plugins/oss/ao_oss.c
+++ b/src/plugins/oss/ao_oss.c
@@ -43,7 +43,7 @@
 #include "ao/plugin.h"
 
 
-static char *ao_oss_options[] = {"dev"};
+static char *ao_oss_options[] = {"dsp"};
 static ao_info ao_oss_info =
 {
 	AO_TYPE_LIVE,
@@ -147,8 +147,8 @@ int ao_plugin_set_option(ao_device *device, const char *key, const char *value)
 	ao_oss_internal *internal = (ao_oss_internal *) device->internal;
 
 
-	if (!strcmp(key, "dev")) {
-		/* Free old string in case "dev" set twice in options */
+	if (!strcmp(key, "dsp")) {
+		/* Free old string in case "dsp" set twice in options */
 		free(internal->dev); 
 		internal->dev = strdup(value);
 	}